declare type DefaultTheme = {
    [key: string]: any;
};
declare type LowercaseCharacter = "a" | "b" | "c" | "d" | "e" | "f" | "g" | "h" | "i" | "j" | "k" | "l" | "m" | "n" | "o" | "p" | "q" | "r" | "s" | "t" | "u" | "v" | "w" | "x" | "y" | "z";
declare type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
declare type NonEmptyString = `${AllCharacter}${string}`;
declare type CSSCustomProperties = `var(--${NonEmptyString})`;
declare type LengthUnit = "vmin" | "vmax" | "vh" | "vw" | "%" | "ch" | "ex" | "em" | "rem" | "in" | "cm" | "mm" | "pt" | "pc" | "px";
declare type CSSLength = `${number}${LengthUnit}` | CSSCustomProperties;
declare function checkIsCSSLength(str: string): str is CSSLength;
interface Spacing {
    none: CSSLength;
    xxs: CSSLength;
    xs: CSSLength;
    sm: CSSLength;
    md: CSSLength;
    mdLg: CSSLength;
    lg: CSSLength;
    lgXl: CSSLength;
    xl: CSSLength;
    xlXXl: CSSLength;
    xxl: CSSLength;
}
interface Sizes {
    xxsmall: CSSLength;
    xsmall: CSSLength;
    small: CSSLength;
    medium: CSSLength;
    large: CSSLength;
    xlarge: CSSLength;
    xxlarge: CSSLength;
}
declare type BaseTheme = Record<string, CSSLength | string | number>;
declare type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? T["space"] : T extends {
    spacing: BaseTheme;
} ? T["spacing"] : Spacing;
declare type ThemeOrDefaultSizes<T> = T extends {
    sizes: BaseTheme;
} ? T["sizes"] : Sizes;
declare type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
declare type SizesOptions = ThemeOrDefaultSizes<DefaultTheme>;
declare const spacing: Record<string, CSSLength>;
declare const sizes: Sizes;
declare type MaybeCSSLength = CSSLength | undefined;
declare type GetSpacingValue = <T>(theme: T & {
    spacing?: BaseTheme;
    space?: BaseTheme;
}, spacingKey: keyof Spacing | keyof SpacingOptions) => MaybeCSSLength;
declare const getSpacingValue: GetSpacingValue;
declare type Gutter = CSSLength | number | keyof SpacingOptions;
declare function getSafeGutter<T extends BaseTheme>(theme: T, gutter?: Gutter): MaybeCSSLength;
declare function validateGutter<T extends {
    gutter?: Gutter;
}>({ gutter }: T, propName: string): void;
declare type GetSizeValue = <T>(theme: T & {
    sizes?: BaseTheme;
}, sizingKey: unknown) => MaybeCSSLength;
declare const getSizeValue: GetSizeValue;
declare type NumberTuple = [number, number];
interface BreakPoints {
    smallOnly: number;
    mediumOnly: NumberTuple;
    largeOnly: NumberTuple;
    xlargeOnly: NumberTuple;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
}
declare type BreakPointTypes = keyof BreakPoints;
declare const breakPoints: BreakPoints;
declare type MergeBreakpoints = (breakPoints: Record<string, unknown>) => BreakPoints;
declare const mergeBreakpoints: MergeBreakpoints;

export { BaseTheme, BreakPointTypes, BreakPoints, CSSLength, Gutter, Sizes, SizesOptions, Spacing, SpacingOptions, breakPoints, checkIsCSSLength, getSafeGutter, getSizeValue, getSpacingValue, mergeBreakpoints, sizes, spacing, validateGutter };
